# PROCESSADOR DE IMAGENS EM PORTUGUES - BRASIL

Este é um pacote de processamento de imagens desenvolvido com base na biblioteca scikit-image com comandos em português do Brasil.

O pacote processador_de_imagem_ptbr é usado para:

	Processamento:
		-  Encontrar taxa de similaridade entre as imagens
		-  Realizar correspondência de histograma
		-  Redimensionar imagem

	Utilidades:
		-  Ler imagem
		-  Salvar imagem
		-  Plotar imagem
		-  Mostrar resultado de combinação das imagens
		-  Plotar histograma

## Instalação

Usar o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalar o processador_de_imagens

```bash
pip install processador_de_imagens
```

## Author
Gabriel Calasans

## License
[MIT](https://choosealicense.com/licenses/mit/)